@@ -133,7 +133,7 @@ def get_sensor_id(a, object_id):
     headers = {'Authorization': 'Bearer {}'.format(a.access_token)}
 
     req = rq.get(url, headers=headers)
-    return req
+    return req.json()[0][0]
 
 def get_measurement_types(a, sensor_id):
 
